"use strict";
/*

This object represents all available syntax slugs and aliases in refractor.
Each key is a canonical syntax slug. Each value is an array of aliases that
will result in the same highlighting as the canonical syntax slug.
ref: https://github.com/wooorm/refractor#syntaxes

This list can be generated from the refractor readme.

1. Open a temporary file in an editor with regex-based find-and-replace
2. Paste the raw contents of the refractor README into the file
   I used https://raw.githubusercontent.com/wooorm/refractor/7372dccc7d0a5c9e0d0d11725e901a43aedc461b/readme.md
3. Delete everything except the checkbox list under the "Syntaxes" heading
4. Run the following regex sets, in order:

    (for each set, copy everything after the colon and space)

    Find: \*   \[x?\s?\] \[`(.*)`\]\((.*)\)(.*)
    Replace with: "$1": [ $3 ],
    Find: - alias
    Replace with empty string.
    Find: `
    Replace with: "

5. Sort lines ascending, if you want
6. Paste the result into this file, just after the "module exports" line,
   and include a closing brace. Save and auto-formatting should handle the rest.
7. Run tests and remove any syntaxes not supported in whatever current version
   of refractor we're using.
*/
/* cSpell:disable */
module.exports = {
    abap: [],
    abnf: [],
    actionscript: [],
    ada: [],
    antlr4: ['g4'],
    apacheconf: [],
    apl: [],
    applescript: [],
    aql: [],
    arduino: [],
    arff: [],
    asciidoc: ['adoc'],
    asm6502: [],
    aspnet: [],
    autohotkey: [],
    autoit: [],
    bash: ['shell'],
    basic: [],
    batch: [],
    bbcode: ['shortcode'],
    bison: [],
    bnf: ['rbnf'],
    brainfuck: [],
    brightscript: [],
    bro: [],
    c: [],
    cil: [],
    clike: [],
    clojure: [],
    cmake: [],
    coffeescript: ['coffee'],
    concurnas: ['conc'],
    cpp: [],
    crystal: [],
    csharp: ['cs', 'dotnet'],
    csp: [],
    css: [],
    d: [],
    dart: [],
    dax: [],
    diff: [],
    django: ['jinja2'],
    'dns-zone-file': ['dns-zone'],
    docker: ['dockerfile'],
    ebnf: [],
    eiffel: [],
    ejs: [],
    elixir: [],
    elm: [],
    erb: [],
    erlang: [],
    etlua: [],
    'excel-formula': ['xls', 'xlsx'],
    factor: [],
    'firestore-security-rules': [],
    flow: [],
    fortran: [],
    fsharp: [],
    ftl: [],
    gcode: [],
    gdscript: [],
    gedcom: [],
    gherkin: [],
    git: [],
    glsl: [],
    gml: ['gamemakerlanguage'],
    go: [],
    graphql: [],
    groovy: [],
    haml: [],
    handlebars: [],
    haskell: ['hs'],
    haxe: [],
    hcl: [],
    hpkp: [],
    hsts: [],
    http: [],
    ichigojam: [],
    icon: [],
    inform7: [],
    ini: [],
    io: [],
    j: [],
    java: [],
    javadoc: [],
    javadoclike: [],
    javascript: ['js'],
    javastacktrace: [],
    jolie: [],
    jq: [],
    jsdoc: [],
    json: [],
    json5: [],
    jsonp: [],
    jsx: [],
    julia: [],
    keyman: [],
    kotlin: [],
    latex: ['context', 'tex'],
    latte: [],
    less: [],
    lilypond: ['ly'],
    liquid: [],
    lisp: ['elisp', 'emacs', 'emacs-lisp'],
    livescript: [],
    llvm: [],
    lolcode: [],
    lua: [],
    makefile: [],
    markdown: ['md'],
    'markup-templating': [],
    markup: ['html', 'mathml', 'svg', 'xml'],
    matlab: [],
    mel: [],
    mizar: [],
    monkey: [],
    moonscript: ['moon'],
    n1ql: [],
    n4js: ['n4jsd'],
    'nand2tetris-hdl': [],
    nasm: [],
    neon: [],
    nginx: [],
    nim: [],
    nix: [],
    nsis: [],
    objectivec: [],
    ocaml: [],
    opencl: [],
    oz: [],
    parigp: [],
    parser: [],
    pascal: ['objectpascal'],
    pascaligo: [],
    pcaxis: ['px'],
    perl: [],
    php: [],
    phpdoc: [],
    plsql: [],
    powerquery: ['mscript', 'pq'],
    powershell: [],
    processing: [],
    prolog: [],
    properties: [],
    protobuf: [],
    pug: [],
    puppet: [],
    pure: [],
    python: ['py'],
    q: [],
    qml: [],
    qore: [],
    r: [],
    reason: [],
    regex: [],
    renpy: [],
    rest: [],
    rip: [],
    roboconf: [],
    robotframework: ['robot'],
    ruby: ['rb'],
    rust: [],
    sas: [],
    sass: [],
    scala: [],
    scheme: [],
    scss: [],
    'shell-session': [],
    smalltalk: [],
    smarty: [],
    solidity: [],
    'solution-file': ['sln'],
    soy: [],
    sparql: ['rq'],
    'splunk-spl': [],
    sqf: [],
    sql: [],
    stylus: [],
    swift: [],
    't4-cs': ['t4'],
    't4-templating': [],
    't4-vb': [],
    tap: [],
    tcl: [],
    textile: [],
    toml: [],
    tsx: [],
    tt2: [],
    turtle: ['trig'],
    twig: [],
    typescript: ['ts'],
    vala: [],
    vbnet: [],
    velocity: [],
    verilog: [],
    vhdl: [],
    vim: [],
    'visual-basic': ['vb'],
    wasm: [],
    wiki: [],
    xeora: ['xeoracube'],
    xojo: [],
    xquery: [],
    yaml: ['yml'],
    zig: [],
};
