"use strict";
// const is = require('unist-util-is')
const visit = require('unist-util-visit');
const surfaceNewlines = require('./surface-newlines');
function rehypePluginFixCodeTokenNewlines() {
    return function transformer(tree) {
        // Visit code elements, and ensure newlines are surfaced
        // as top-level children, rather than nested within tokens
        // as rehype-prism / refractor does by default
        visit(tree, 'element', (node) => {
            // We're looking for code elements
            // (note these are distinct from `inlineCode` elements)
            if (node.tagName !== 'code')
                return;
            // The code element must have children
            if (!node.children || node.children.length === 0)
                return;
            // I'm deleting all node.position values here,
            // because modifications to the tree, which involve
            // the replacement of nodes, feel like they kind of
            // invalidate the position values. I'm not sure if
            // this is the right approach. Trying to reconstruct
            // updated position values seems a bit over-the-top...
            // But leaving in the potentially misleading position
            // values also didn't feel great
            visit(node.children, (node) => delete node.position);
            // Then, surfacing newlines, re-assigning to the children prop
            node.children = surfaceNewlines(node.children);
        });
    };
}
module.exports = rehypePluginFixCodeTokenNewlines;
